@@ -1,7 +1,7 @@
 /* callbacks.c
 *
-* Copyright 2002 Sun Microsystems, Inc.,
-* Copyright 2002 University Of Toronto
+* Copyright 2002-2009 Sun Microsystems, Inc.,
+* Copyright 2002-2009 University Of Toronto
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
@@ -47,7 +47,6 @@
 #include "gok-spy.h"
 #include "gok-data.h"
 
-static gboolean input_event_received = FALSE;
 
 static GdkFilterReturn
 gok_xkb_filter (GdkXEvent *gdk_xevent, GdkEvent *event, gpointer data)
@@ -61,60 +60,12 @@ gok_xkb_filter (GdkXEvent *gdk_xevent, GdkEvent *event, gpointer data)
 	return GDK_FILTER_CONTINUE;
 }
 
-static GdkFilterReturn
-gok_input_extension_filter (GdkXEvent *gdk_xevent, GdkEvent *event, gpointer data)
-{
-	XEvent *xevent = gdk_xevent;
-#ifdef HAVE_XINPUT
-	
-	if (xevent->type == gok_input_types[GOK_INPUT_TYPE_MOTION])
-	{
-		XDeviceMotionEvent *motion = (XDeviceMotionEvent *) xevent;
-#if 0
-		if (!input_event_received && motion->deviceid != gok_input_get_current ()->device->device_id)
-		{
-			GokInput *input = gok_input_find_by_device_id (motion->deviceid, TRUE);
-			gok_input_mismatch_warn (input->info);
-		}
-#endif
-		gok_main_motion_listener (motion->axes_count, motion->axis_data, 
-					  motion->device_state, (long) motion->time);
-	}
-	else if ((xevent->type == gok_input_types[GOK_INPUT_TYPE_BUTTON_PRESS]) || 
-		 (xevent->type == gok_input_types[GOK_INPUT_TYPE_BUTTON_RELEASE]))
-	{
-		XDeviceButtonEvent *button = (XDeviceButtonEvent *) xevent;
-#if 0
-		if (!input_event_received && button->deviceid != gok_input_get_current ()->device->device_id)
-		{
-			GokInput *input = gok_input_find_by_device_id (button->deviceid, TRUE);
-			gok_input_mismatch_warn (input->info);
-		}
-#endif
-		gok_main_button_listener (button->button, 
-					  (xevent->type == gok_input_types[GOK_INPUT_TYPE_BUTTON_PRESS]) ? 1 : 0, 
-					  button->state, 
-					  button->time);
-	}
-	else 
-	{
-		return GDK_FILTER_CONTINUE;
-	}
-	input_event_received = TRUE;
-/*	gok_input_close_others (gok_input_get_current ()); */
-
-	return GDK_FILTER_REMOVE;
-#else
-	return GDK_FILTER_CONTINUE;
-#endif
-}
-
 void
 on_window1_destroy                     (GtkObject       *object,
                                         gpointer         user_data)
 {
 	/* this must be done before calling SPI_event_quit */
-	gok_spy_deregister_mousebuttonlistener ((void *)gok_main_button_listener);
+	gok_spy_deregister_mousebuttonlistener ((void *)gok_main_mouse_button_listener);
 
 	SPI_event_quit ();
 }
@@ -123,16 +74,17 @@ void
 on_window1_realize                     (GtkWidget       *widget,
                                         gpointer         user_data)
 {
-  gboolean is_dock = (gboolean) user_data;
+  struct gok_window_realize_data *window_realize_data = (struct gok_window_realize_data *) user_data;
   GdkKeymap *map = gdk_keymap_get_default ();
 
-  if (is_dock) {
+  gok_main_center_corepointer (widget);
+
+  if (window_realize_data->is_dock) {
 	  gok_main_set_wm_dock (TRUE);
   }
   else {
 	  if (widget->window) {
-		  gdk_window_set_decorations (widget->window, GDK_DECOR_ALL | 
-					      GDK_DECOR_MINIMIZE | GDK_DECOR_MAXIMIZE);
+		  gdk_window_set_decorations (widget->window, GDK_DECOR_ALL | GDK_DECOR_MINIMIZE | GDK_DECOR_MAXIMIZE);
 		  gdk_window_set_functions (widget->window, GDK_FUNC_MOVE | GDK_FUNC_RESIZE);
 	  }
   }
@@ -141,16 +93,15 @@ on_window1_realize                     (GtkWidget       *widget,
 
   if (!gok_keyboard_xkb_select (GDK_WINDOW_XDISPLAY (widget->window)))
 	  g_warning ("Could not register for XKB events!");
+  
+  if (window_realize_data->use_libusb == FALSE) {
+  	gok_input_init (gok_input_extension_filter);
+  }
 
-  /* gok_input_open_all (); */
-  gok_input_init (gok_input_get_current (), gok_input_extension_filter);
+  gdk_window_add_filter (NULL, gok_xkb_filter, NULL);
+  g_signal_connect (map, "keys-changed", (GCallback) gok_spy_keymap_listener, NULL);
 
-  gdk_window_add_filter (NULL,
-			 gok_xkb_filter,
-			 NULL);
-
-  g_signal_connect (map, "keys-changed",
-		    (GCallback) gok_spy_keymap_listener, NULL);
+  g_free(window_realize_data);
 }
 
 
@@ -216,14 +167,20 @@ on_window1_enter_notify_event         (GtkWidget        *widget,
 				       gpointer          user_data)
 {	
         GdkCursor *cursor;
-        if (gok_data_get_drive_corepointer ()) {
-	  gok_data_set_drive_corepointer (FALSE);
-	  gok_main_set_cursor (NULL);
-	}
-	else {
-	  cursor = gdk_cursor_new (GDK_ARROW);
-	  gok_main_set_cursor (cursor);
-	  gdk_cursor_destroy (cursor);
+	if (event->detail != GDK_NOTIFY_INFERIOR &&
+	    event->detail != GDK_NOTIFY_NONLINEAR_VIRTUAL) 
+	{
+		if (gok_data_get_drive_corepointer ()) 
+		{
+			gok_data_set_drive_corepointer (FALSE);
+			gok_main_set_cursor (NULL);
+		}
+		else 
+		{
+			cursor = gdk_cursor_new (GDK_ARROW);
+			gok_main_set_cursor (cursor);
+			gdk_cursor_unref (cursor);
+		}
 	}
 	return FALSE;
 }
@@ -868,6 +825,7 @@ on_axis_selection_spinbutton_changed   (GtkEditable     *editable,
 }
 
 
+
 void
 on_activate_on_enter_button_toggled    (GtkToggleButton *togglebutton,
                                         gpointer         user_data)
