@@ -1,7 +1,7 @@
 /* gok-key.c
 *
-* Copyright 2001,2002 Sun Microsystems, Inc.,
-* Copyright 2001,2002 University Of Toronto
+* Copyright 2001-2009 Sun Microsystems, Inc.,
+* Copyright 2001-2009 University Of Toronto
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
@@ -1911,7 +1911,7 @@ gok_key_update_toggle_state (GokKey *pKey)
 		if (pKey->ComponentState.radio) {
 			GOK_BUTTON (pKey->pButton)->indicator_type = /*g_strdup( ?*/ "radiobutton" /*)*/;
 		}
-		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (pKey->pButton),
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (pKey->pButton),
 					      is_active);
 	}
 	gok_log_leave();
