@@ -1,7 +1,7 @@
 /* gok-page-keysizespace.c
 *
-* Copyright 2002 Sun Microsystems, Inc.,
-* Copyright 2002 University Of Toronto
+* Copyright 2002-2009 Sun Microsystems, Inc.,
+* Copyright 2002-2009 University Of Toronto
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
@@ -37,6 +37,8 @@ static gboolean m_bUseGtkPlusTheme;
 static gint m_keywidthBackup, m_keyheightBackup, m_spacingBackup; 
 static gboolean m_bUseGtkPlusThemeBackup;
 
+static GtkWidget *sample_buttons[4];
+
 /**
 * gok-settings-page-keysizespace-initialize
 * @pWindowSettings: Pointer to the settings dialog window.
@@ -48,15 +50,11 @@ static gboolean m_bUseGtkPlusThemeBackup;
 **/
 gboolean gok_settings_page_keysizespace_initialize (GladeXML * xml)
 {
-	GtkWidget* pButtonExample1;
-	GtkWidget* pButtonExample2;
-	GtkWidget* pButtonExample3;
-	GtkWidget* pButtonExample4;
 	GtkWidget* fixedKeySpacing;
 	GtkWidget* pWindowSettings;
 	GtkWidget* widget;
-	GtkTooltips *tooltips;
-	
+	gint i;
+
 	g_assert (xml != NULL);
 
 	/* initialize this data */
@@ -68,36 +66,24 @@ gboolean gok_settings_page_keysizespace_initialize (GladeXML * xml)
 	/* backup the initial settings */
 	gok_settings_page_keysizespace_backup();
 
-	tooltips = gtk_tooltips_new ();
-
 	/* create the example buttons for key size/spacing */
-	/* I'm doing this here because Glade generates a setusize that I don't want */
+	/* I'm doing this here because Glade doesn't know about GokButtons */
 	
 	/* first, get the fixed area that holds the keys */
 	fixedKeySpacing =  glade_xml_get_widget (xml, "fixedKeySpacing");
 	g_assert (fixedKeySpacing != NULL);
  	pWindowSettings = glade_xml_get_widget (xml, "dialogSettings");
 	g_assert (pWindowSettings != NULL);
-	
-	pButtonExample1 = glade_xml_get_widget (xml, "buttonExample1");
-	g_assert (pButtonExample1 != NULL);
-	gtk_widget_set_name (pButtonExample1, "StyleButtonNormal"); 
-	gok_settings_page_keysizespace_set_label_name (pButtonExample1);
 
-	pButtonExample2 = glade_xml_get_widget (xml, "buttonExample2");
-	g_assert (pButtonExample2 != NULL);
-	gtk_widget_set_name (pButtonExample2, "StyleButtonNormal"); 
-	gok_settings_page_keysizespace_set_label_name (pButtonExample2);
-
-	pButtonExample3 = glade_xml_get_widget (xml, "buttonExample3");
-	g_assert (pButtonExample3 != NULL);
-	gtk_widget_set_name (pButtonExample3, "StyleButtonNormal"); 
-	gok_settings_page_keysizespace_set_label_name (pButtonExample3);
-
-	pButtonExample4 = glade_xml_get_widget (xml, "buttonExample4");
-	g_assert (pButtonExample4 != NULL);
-	gtk_widget_set_name (pButtonExample4, "StyleButtonNormal"); 
-	gok_settings_page_keysizespace_set_label_name (pButtonExample4);
+	for (i = 0; i < 4; ++i)
+	{
+		sample_buttons[i] = gok_button_new_with_label (_("Button"), IMAGE_PLACEMENT_LEFT);
+		g_assert (sample_buttons[i] != NULL);
+		gtk_widget_set_name (sample_buttons[i], "StyleButtonNormal"); 
+		gok_settings_page_keysizespace_set_label_name (sample_buttons[i]);
+		gtk_container_add (GTK_CONTAINER (fixedKeySpacing), sample_buttons[i]);
+		gtk_widget_show (sample_buttons[i]);
+	}
 
 	/* get the settings from the gok_data and update the controls */
 	gok_settings_page_keysizespace_refresh();
@@ -302,14 +288,10 @@ gboolean gok_settings_page_keysizespace_revert ()
 **/
 void gok_settings_page_keysizespace_display_keysizespacing (gint KeyWidth, gint KeyHeight, gint Space)
 {
-
-	GtkWidget* pButtonKey1;
-	GtkWidget* pButtonKey2;
-	GtkWidget* pButtonKey3;
-	GtkWidget* pButtonKey4;
 	GtkWidget* pFixedKeyspacing;
 	GtkWidget* pWindowSettings;
 	GtkRequisition requisitionSizeFixed;
+	gint i;
 	gint left;
 	gint top;
 	gint width;
@@ -350,16 +332,6 @@ void gok_settings_page_keysizespace_display_keysizespacing (gint KeyWidth, gint
 		Space = MAX_KEY_SPACING;
 	}
 
-	/* get pointers to the example keys */
-	pButtonKey1 = glade_xml_get_widget (gok_settingsdialog_get_xml(), "buttonExample1");
-	g_assert (pButtonKey1 != NULL);
-	pButtonKey2 = glade_xml_get_widget (gok_settingsdialog_get_xml(), "buttonExample2");
-	g_assert (pButtonKey2 != NULL);
-	pButtonKey3 = glade_xml_get_widget (gok_settingsdialog_get_xml(), "buttonExample3");
-	g_assert (pButtonKey3 != NULL);
-	pButtonKey4 = glade_xml_get_widget (gok_settingsdialog_get_xml(), "buttonExample4");
-	g_assert (pButtonKey4 != NULL);
-
 	/* get the container that holds the 'keyspace' buttons */
 	pFixedKeyspacing =  glade_xml_get_widget (gok_settingsdialog_get_xml(), "fixedKeySpacing");
 	g_assert (pFixedKeyspacing != NULL);
@@ -377,21 +349,21 @@ void gok_settings_page_keysizespace_display_keysizespacing (gint KeyWidth, gint
 			
 	if (GDK_IS_DRAWABLE(pWindowSettings->window) == TRUE)
 	{
-		gdk_window_get_size (pWindowSettings->window, &width, NULL);
+		gdk_drawable_get_size (pWindowSettings->window, &width, NULL);
 		left = ((width - 32) - ((KeyWidth * 2) + Space)) / 2;
 	}
 
 	/* resize the buttons */
-	gtk_widget_set_size_request (pButtonKey1, KeyWidth, KeyHeight);
-	gtk_widget_set_size_request (pButtonKey2, KeyWidth, KeyHeight);
-	gtk_widget_set_size_request (pButtonKey3, KeyWidth, KeyHeight);
-	gtk_widget_set_size_request (pButtonKey4, KeyWidth, KeyHeight);
+	for (i = 0; i < 4; ++i)
+	{
+		gtk_widget_set_size_request (sample_buttons[i], KeyWidth, KeyHeight);
+	}
 
 	/* position the buttons */
-	gtk_fixed_move (GTK_FIXED(pFixedKeyspacing), pButtonKey1, left, top);
-	gtk_fixed_move (GTK_FIXED(pFixedKeyspacing), pButtonKey2, left + Space + KeyWidth, top);
-	gtk_fixed_move (GTK_FIXED(pFixedKeyspacing), pButtonKey3, left, top + Space + KeyHeight);
-	gtk_fixed_move (GTK_FIXED(pFixedKeyspacing), pButtonKey4, left + Space + KeyWidth, top + Space + KeyHeight);
+	gtk_fixed_move (GTK_FIXED(pFixedKeyspacing), sample_buttons[0], left, top);
+	gtk_fixed_move (GTK_FIXED(pFixedKeyspacing), sample_buttons[1], left + Space + KeyWidth, top);
+	gtk_fixed_move (GTK_FIXED(pFixedKeyspacing), sample_buttons[2], left, top + Space + KeyHeight);
+	gtk_fixed_move (GTK_FIXED(pFixedKeyspacing), sample_buttons[3], left + Space + KeyWidth, top + Space + KeyHeight);
 
 	m_keywidth = KeyWidth;
 	m_keyheight = KeyHeight;
